==> zhongyan-manage-service-api-0.0.1-20211221.025057-80-sources.jar: cn/com/duiba/cloud/manage/service/api/model/dto/report/export/TobaccoCountExportData.java <==
package cn.com.duiba.cloud.manage.service.api.model.dto.report.export;

import com.alibaba.excel.annotation.ExcelProperty;
import java.io.Serializable;
import java.util.Date;
import lombok.Data;

/**
 * @author xuanhongjian
 */
@Data
@SuppressWarnings("all")
public class TobaccoCountExportData implements Serializable {

    private static final long serialVersionUID = 1102718850533441228L;
    @ExcelProperty("时间")
    private Date curDate;

    @ExcelProperty({"1.橙中支（L）","码数"})
    private Long firstQrcodeCout;
    @ExcelProperty({"2.江南韵","码数"})
    private Long secondQrcodeCount;
    @ExcelProperty({"3.楼外楼","码数"})
    private Long thirdQrcodeCount;
    @ExcelProperty({"4.天外天","码数"})
    private Long fourQrcodeCount;
    @ExcelProperty({"5.山外山","码数"})
    private Long fiveQrcodeCount;
    @ExcelProperty({"6.休闲细支","码数"})
    private Long sixQrcodeCount;
    @ExcelProperty({"7.橙中支","码数"})
    private Long sevenQrcodeCount;

    @ExcelProperty({"1.橙中支（L）","条码"})
    private Long firstCartonQrcodeCount;
    @ExcelProperty({"2.江南韵","条码"})
    private Long secondCartonQrcodeCount;
    @ExcelProperty({"3.楼外楼","条码"})
    private Long thirdCartonQrcodeCount;
    @ExcelProperty({"4.天外天","条码"})
    private Long fourCartonQrcodeCount;
    @ExcelProperty({"5.山外山","条码"})
    private Long fiveCartonQrcodeCount;
    @ExcelProperty({"6.休闲细支","条码"})
    private Long sixCartonQrcodeCount;
    @ExcelProperty({"7.橙中支","条码"})
    private Long sevenCartonQrcodeCount;

    @ExcelProperty({"1.橙中支（L）","包码"})
    private Long firstPackQrcodeCount;
    @ExcelProperty({"2.江南韵","包码"})
    private Long secondPackQrcodeCount;
    @ExcelProperty({"3.楼外楼","包码"})
    private Long thirdPackQrcodeCount;
    @ExcelProperty({"4.天外天","包码"})
    private Long fourPackQrcodeCount;
    @ExcelProperty({"5.山外山","包码"})
    private Long fivePackQrcodeCount;
    @ExcelProperty({"6.休闲细支","包码"})
    private Long sixPackQrcodeCount;
    @ExcelProperty({"7.橙中支","包码"})
    private Long sevenPackQrcodeCount;

    @ExcelProperty({"1.橙中支（L）","人数"})
    private Long firstUv;
    @ExcelProperty({"2.江南韵","人数"})
    private Long secondUv;
    @ExcelProperty({"3.楼外楼","人数"})
    private Long thirdUv;
    @ExcelProperty({"4.天外天","人数"})
    private Long fourUv;
    @ExcelProperty({"5.山外山","人数"})
    private Long fiveUv;
    @ExcelProperty({"6.休闲细支","人数"})
    private Long sixUv;
    @ExcelProperty({"7.橙中支","人数"})
    private Long sevenUv;

    @ExcelProperty({"1.橙中支（L）","次数"})
    private Long firstPv;
    @ExcelProperty({"2.江南韵","次数"})
    private Long secondPv;
    @ExcelProperty({"3.楼外楼","次数"})
    private Long thirdPv;
    @ExcelProperty({"4.天外天","次数"})
    private Long fourPv;
    @ExcelProperty({"5.山外山","次数"})
    private Long fivePv;
    @ExcelProperty({"6.休闲细支","次数"})
    private Long sixPv;
    @ExcelProperty({"7.橙中支","次数"})
    private Long sevenPv;
}

==> zhongyan-manage-service-api-3.0.51-sources.jar: cn/com/duiba/cloud/manage/service/api/model/dto/report/export/TobaccoCountExportData.java <==
package cn.com.duiba.cloud.manage.service.api.model.dto.report.export;

import com.alibaba.excel.annotation.ExcelProperty;
import java.io.Serializable;
import java.util.Date;
import lombok.Data;

/**
 * @author xuanhongjian
 */
@Data
@SuppressWarnings("all")
public class TobaccoCountExportData implements Serializable {

    private static final long serialVersionUID = 1102718850533441228L;
    @ExcelProperty("时间")
    private Date curDate;

    @ExcelProperty({"1.橙中支(L)","码数"})
    private Long eightQrcodeCount;
    @ExcelProperty({"1.橙中支(L)","条码"})
    private Long eightCartonQrcodeCount;
    @ExcelProperty({"1.橙中支(L)","包码"})
    private Long eightPackQrcodeCount;
    @ExcelProperty({"1.橙中支(L)","人数"})
    private Long eightUv;
    @ExcelProperty({"1.橙中支(L)","次数"})
    private Long eightPv;

    @ExcelProperty({"2.江南韵","码数"})
    private Long fiveQrcodeCount;
    @ExcelProperty({"2.江南韵","条码"})
    private Long fiveCartonQrcodeCount;
    @ExcelProperty({"2.江南韵","包码"})
    private Long fivePackQrcodeCount;
    @ExcelProperty({"2.江南韵","人数"})
    private Long fiveUv;
    @ExcelProperty({"2.江南韵","次数"})
    private Long fivePv;


    @ExcelProperty({"3.楼外楼","码数"})
    private Long fourQrcodeCount;
    @ExcelProperty({"3.楼外楼","条码"})
    private Long fourCartonQrcodeCount;
    @ExcelProperty({"3.楼外楼","包码"})
    private Long fourPackQrcodeCount;
    @ExcelProperty({"3.楼外楼","人数"})
    private Long fourUv;
    @ExcelProperty({"3.楼外楼","次数"})
    private Long fourPv;

    @ExcelProperty({"4.天外天","码数"})
    private Long thirdQrcodeCount;
    @ExcelProperty({"4.天外天","条码"})
    private Long thirdCartonQrcodeCount;
    @ExcelProperty({"4.天外天","包码"})
    private Long thirdPackQrcodeCount;
    @ExcelProperty({"4.天外天","人数"})
    private Long thirdUv;
    @ExcelProperty({"4.天外天","次数"})
    private Long thirdPv;

    @ExcelProperty({"5.山外山","码数"})
    private Long secondQrcodeCount;
    @ExcelProperty({"5.山外山","条码"})
    private Long secondCartonQrcodeCount;
    @ExcelProperty({"5.山外山","包码"})
    private Long secondPackQrcodeCount;
    @ExcelProperty({"5.山外山","人数"})
    private Long secondUv;
    @ExcelProperty({"5.山外山","次数"})
    private Long secondPv;

    @ExcelProperty({"6.休闲细支","码数"})
    private Long firstQrcodeCount;
    @ExcelProperty({"6.休闲细支","条码"})
    private Long firstCartonQrcodeCount;
    @ExcelProperty({"6.休闲细支","包码"})
    private Long firstPackQrcodeCount;
    @ExcelProperty({"6.休闲细支","人数"})
    private Long firstUv;
    @ExcelProperty({"6.休闲细支","次数"})
    private Long firstPv;

    @ExcelProperty({"7.橙中支","码数"})
    private Long sevenQrcodeCount;
    @ExcelProperty({"7.橙中支","条码"})
    private Long sevenCartonQrcodeCount;
    @ExcelProperty({"7.橙中支","包码"})
    private Long sevenPackQrcodeCount;
    @ExcelProperty({"7.橙中支","人数"})
    private Long sevenUv;
    @ExcelProperty({"7.橙中支","次数"})
    private Long sevenPv;
}
